ParseError

Enum ParseError 

#[non_exhaustive]
pub enum ParseError { BufferTooShort { context: &'static str, minimum: usize, actual: usize, }, InvalidLength { context: &'static str, value: usize, }, Malformed { context: &'static str, }, Truncated { context: &'static str, expected: usize, actual: usize, }, CompressionLoop { context: &'static str, }, InvalidCompression { context: &'static str, }, InvalidUtf8 { context: &'static str, }, }
Structured error returned by try_from_* parsing APIs.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


BufferTooShort

The input buffer was shorter than the protocol minimum.

Fields

context: &'static str

Human-readable parse context.

minimum: usize

Minimum required number of bytes.

actual: usize

Actual number of bytes available.



InvalidLength

A length-like field contained an invalid value.

Fields

context: &'static str

Human-readable parse context.

value: usize

Parsed value that failed validation.



Malformed

The packet contains a malformed header field.

Fields

context: &'static str

Human-readable parse context.



Truncated

The packet payload was truncated relative to its header lengths.

Fields

context: &'static str

Human-readable parse context.

expected: usize

Expected number of bytes.

actual: usize

Actual number of bytes available.



CompressionLoop

Parsing failed because a compression loop or excessive indirection was detected.

Fields

context: &'static str

Human-readable parse context.



InvalidCompression

Parsing failed because an unsupported or invalid pointer/compression form was encountered.

Fields

context: &'static str

Human-readable parse context.



InvalidUtf8

A UTF-8 conversion failed while parsing text-like data.

Fields

context: &'static str

Human-readable parse context.